@@ -10,8 +10,7 @@ from unittest.mock import Mock
 import pytest
 
 import can
-from can.interfaces.kvaser import canlib
-from can.interfaces.kvaser import constants
+from can.interfaces.kvaser import canlib, constants
 
 
 class KvaserTest(unittest.TestCase):
@@ -37,7 +36,7 @@ class KvaserTest(unittest.TestCase):
 
         self.msg = {}
         self.msg_in_cue = None
-        self.bus = can.Bus(channel=0, bustype="kvaser")
+        self.bus = can.Bus(channel=0, interface="kvaser")
 
     def tearDown(self):
         if self.bus:
@@ -149,7 +148,7 @@ class KvaserTest(unittest.TestCase):
     def test_canfd_default_data_bitrate(self):
         canlib.canSetBusParams.reset_mock()
         canlib.canSetBusParamsFd.reset_mock()
-        can.Bus(channel=0, bustype="kvaser", fd=True)
+        can.Bus(channel=0, interface="kvaser", fd=True)
         canlib.canSetBusParams.assert_called_once_with(
             0, constants.canFD_BITRATE_500K_80P, 0, 0, 0, 0, 0
         )
@@ -161,7 +160,7 @@ class KvaserTest(unittest.TestCase):
         canlib.canSetBusParams.reset_mock()
         canlib.canSetBusParamsFd.reset_mock()
         data_bitrate = 2000000
-        can.Bus(channel=0, bustype="kvaser", fd=True, data_bitrate=data_bitrate)
+        can.Bus(channel=0, interface="kvaser", fd=True, data_bitrate=data_bitrate)
         bitrate_constant = canlib.BITRATE_FD[data_bitrate]
         canlib.canSetBusParams.assert_called_once_with(
             0, constants.canFD_BITRATE_500K_80P, 0, 0, 0, 0, 0
@@ -172,7 +171,7 @@ class KvaserTest(unittest.TestCase):
         canlib.canSetBusParams.reset_mock()
         canlib.canSetBusParamsFd.reset_mock()
         data_bitrate = 123456
-        can.Bus(channel=0, bustype="kvaser", fd=True, data_bitrate=data_bitrate)
+        can.Bus(channel=0, interface="kvaser", fd=True, data_bitrate=data_bitrate)
         canlib.canSetBusParams.assert_called_once_with(
             0, constants.canFD_BITRATE_500K_80P, 0, 0, 0, 0, 0
         )
